/******************************************************************************
*  List of available character classes (singleton pattern).
*
*  @author   Daniel R. Collins (dcollins@superdan.net)
*  @since    2014-05-22
*  @version  1.0
******************************************************************************/

import java.io.IOException; 

public class ClassList {
	//--------------------------------------------------------------------------
	//  Constants
	//--------------------------------------------------------------------------

	/** Name of file with class information. */
	final String CLASS_FILE = "Classes.csv";

	//--------------------------------------------------------------------------
	//  Fields
	//--------------------------------------------------------------------------

	/** The singleton class instance. */
	static ClassList instance = null;
	
	/** Array of ClassInfo records. */
	ClassInfo[] classInfoArray;

	//--------------------------------------------------------------------------
	//  Constructors
	//--------------------------------------------------------------------------

	/**
	*  Constructor (read from dedicated file).
	*/
	protected ClassList () throws IOException {

		// Read the text tables from file
		InfoTable[] infoTables = InfoTable.readTableFile(CLASS_FILE);
		InfoTable master = infoTables[0];

		// Parse each class into ClassInfo
		classInfoArray = new ClassInfo[master.numRows()];
		for (int i = 0; i < master.numRows(); i++) {
			String name = master.getCell(i, 0);

			// Find corresponding level/XP table
			for (InfoTable xpTable: infoTables) {
				if (xpTable.name().equals(name)) {
					classInfoArray[i] = new ClassInfo(i, master, xpTable);
					break;
				}
			}
		}		
	}

	//--------------------------------------------------------------------------
	//  Methods
	//--------------------------------------------------------------------------
	public int size() { return classInfoArray.length; }
	public ClassInfo get (int index) { return classInfoArray[index]; }

	/**
	*  Access the singleton class instance.
	*/
	public static ClassList getInstance() {
		if (instance == null) {
			try {
				instance = new ClassList();
			}
			catch (IOException e) {
				System.out.println("Failed to read the Classes file.");
			}
		}
		return instance;
	}

	/**
	*  Get ClassInfo record for a given class name.
	*/
	public static ClassInfo getInfo (String name) {
		ClassList cl = getInstance();
		for (int i = 0; i < cl.size(); i++) {
			ClassInfo info = cl.get(i);
			if (info.getName().equals(name))
				return info;
		}
		return null;
	}

	/**
	*  Main test method.
	*/
	public static void main (String[] args) {

		// Print basics of entire list
		ClassList cl = ClassList.getInstance();
		for (int i = 0; i < cl.size(); i++) {
			System.out.println(cl.get(i));
		}
		System.out.println();
		
		// Print specifics for Fighter class
		ClassInfo info = ClassList.getInfo("Fighter");
		System.out.println(info);
		for (int i = 1; i <= 20; i++) {
			System.out.println(i + "|" + info.getTitle(i) + "|" 
				+ info.getExperienceReq(i) + "|" + info.getAttackBonus(i));
		}
	}
}

