/******************************************************************************
*  Record of a class gained by a persona (XP, level, hit points, etc.).
*
*  @author   Daniel R. Collins (dcollins@superdan.net)
*  @since    2014-05-22
*  @version  1.0
******************************************************************************/

public class ClassRecord {
	//--------------------------------------------------------------------------
	//  Fields
	//--------------------------------------------------------------------------

	/** Class info for this class. */
	ClassInfo info;

	/** Level in this class. */
	int level;

	/** Hit points earned for this class. */
	int hitPoints;

	/** Experience points earned towards this class. */
	int XP;

	//--------------------------------------------------------------------------
	//  Constructors
	//--------------------------------------------------------------------------

	/**
	*  Constructor (by ClassInfo, 1st level, random hit points).
	*/
	public ClassRecord (ClassInfo info, int hpBonus) {
		this(info, 1, 1, 0);
		hitPoints = info.getHitDiceInc(1).rollPlus(hpBonus);
	}

	/**
	*  Constructor (full fields).
	*/
	public ClassRecord (ClassInfo info, int level, int hitPoints, int XP) {
		this.info = info;
		this.level = level;
		this.hitPoints = hitPoints;
		this.XP = XP;
	}

	//--------------------------------------------------------------------------
	//  Methods
	//--------------------------------------------------------------------------
	public ClassInfo getInfo () { return info; }
	public int getLevel () { return level; }
	public int getHitPoints () { return hitPoints; }
	public int getXP () { return XP; }

	/**
	*  Returns the base attack bonus for this class/level.
	*/
	public int attackBonus () {
		return info.getAttackBonus(level);
	}

	/**
	*  Add XP to this class & handle level-ups.
	*  TODO: Having the Con bonus in here is pretty clunky.
	*/
	public void addXP (int awardXP, int hpBonus) {
		XP += awardXP;
		if (XP >= info.getExperienceReq(level+1)) {
			level++;

			// Increase hit points
			Dice newDice = info.getHitDiceInc(level);
			if (newDice.getNumber() > 0)
				hitPoints += newDice.rollPlus(hpBonus);
			else 
				hitPoints += newDice.getAddition();
				
			// Prevent multiple level bumps at once
			XP = Math.min(XP, info.getExperienceReq(level+1)-1);
		}
	}

	/**
	*  Returns a string representation of this class record.
	*/
	public String toString() {
		return info.getName() + "(" + level + ", " + hitPoints + ", " + XP + ")";
	}	

	/**
	*  Main test method.
	*/
	public static void main (String[] args) {
	}
}

