/******************************************************************************
*  List of available monster types (singleton pattern).
*
*  @author   Daniel R. Collins (dcollins@superdan.net)
*  @since    2014-07-18
*  @version  1.0
******************************************************************************/

import java.io.IOException; 

public class MonsterList {
	//--------------------------------------------------------------------------
	//  Constants
	//--------------------------------------------------------------------------

	/** Name of file with monster information. */
	final String MONSTER_FILE = "Monsters.csv";

	//--------------------------------------------------------------------------
	//  Fields
	//--------------------------------------------------------------------------

	/** The singleton class instance. */
	static MonsterList instance = null;
	
	/** Array of Creature records. */
	Creature[] creatureArray;

	//--------------------------------------------------------------------------
	//  Constructors
	//--------------------------------------------------------------------------

	/**
	*  Constructor (read from dedicated file).
	*/
	protected MonsterList () throws IOException {

		// Read the text table from file
		InfoTable[] tableArray = InfoTable.readTableFile(MONSTER_FILE);
		InfoTable table = tableArray[0];

		// Parse each monster into Creature
		creatureArray = new Creature[table.numRows()];
		for (int i = 0; i < table.numRows(); i++) {
			creatureArray[i] = new Creature(i, table);
		}		
	}

	//--------------------------------------------------------------------------
	//  Methods
	//--------------------------------------------------------------------------
	public int size() { return creatureArray.length; }
	public Creature get (int index) { return creatureArray[index]; }

	/**
	*  Access the singleton class instance.
	*/
	public static MonsterList getInstance() {
		if (instance == null) {
			try {
				instance = new MonsterList();
			}
			catch (IOException e) {
				System.out.println("Failed to read the Monsters file.");
			}
		}
		return instance;
	}

	/**
	*  Main test method.
	*/
	public static void main (String[] args) {
		MonsterList ml = MonsterList.getInstance();
		for (int i = 0; i < ml.size(); i++) {
			System.out.println(ml.get(i));
		}
		System.out.println();
	}
}

